# [1.3.0](https://gitlab.com/blissfulreboot/python/git-workspace/compare/v1.2.0...v1.3.0) (2020-06-23)


### Bug Fixes

* print also stderr from operation scripts ([e3657f3](https://gitlab.com/blissfulreboot/python/git-workspace/commit/e3657f366c7174ef8235e5bf82a805710ec4e4ce))


### Features

* Add command to list available operations ([75a4562](https://gitlab.com/blissfulreboot/python/git-workspace/commit/75a456227209892a537799b22ad37a014f1974ee))

# [1.2.0](https://gitlab.com/blissfulreboot/python/git-workspace/compare/v1.1.2...v1.2.0) (2020-06-22)


### Features

* define environment variables for operations ([d3b76d3](https://gitlab.com/blissfulreboot/python/git-workspace/commit/d3b76d3db9945f0b1f482669d5d6a8f57253b981))

## [1.1.2](https://gitlab.com/blissfulreboot/python/git-workspace/compare/v1.1.1...v1.1.2) (2020-06-22)


### Bug Fixes

* further corrections to in repository commands ([829b2de](https://gitlab.com/blissfulreboot/python/git-workspace/commit/829b2dea1e681c135d2d03da6bbc4c06b9d8b820))

## [1.1.1](https://gitlab.com/blissfulreboot/python/git-workspace/compare/v1.1.0...v1.1.1) (2020-06-22)


### Bug Fixes

* clicommand arg is being accessed wrong ([06b9376](https://gitlab.com/blissfulreboot/python/git-workspace/commit/06b937611aa8d3dbafb0a76bb4bce2614ab2d4db))

# [1.1.0](https://gitlab.com/blissfulreboot/python/git-workspace/compare/v1.0.5...v1.1.0) (2020-06-21)


### Features

* add graphops pipelines ([e760c50](https://gitlab.com/blissfulreboot/python/git-workspace/commit/e760c50e6aad54bdc17df99b15b27e41599c5eeb))

## [1.0.5](https://gitlab.com/blissfulreboot/python/git-workspace/compare/v1.0.4...v1.0.5) (2020-06-21)


### Bug Fixes

* install as executable script ([04eb893](https://gitlab.com/blissfulreboot/python/git-workspace/commit/04eb893fe5d7c407aadd36ac2a3593108d943375))

## [1.0.4](https://gitlab.com/blissfulreboot/python/git-workspace/compare/v1.0.3...v1.0.4) (2020-06-20)


### Bug Fixes

* remove long description as a quick upload fix ([a8d40fc](https://gitlab.com/blissfulreboot/python/git-workspace/commit/a8d40fc63e1889d74aad5149dfa1370032f6519e))

## [1.0.3](https://gitlab.com/blissfulreboot/python/git-workspace/compare/v1.0.2...v1.0.3) (2020-06-20)


### Bug Fixes

* add readme.md to the package_data ([6ddb220](https://gitlab.com/blissfulreboot/python/git-workspace/commit/6ddb2202a1fa25774afe3ef48ad59a1c8308c76e))

## [1.0.2](https://gitlab.com/blissfulreboot/python/git-workspace/compare/v1.0.1...v1.0.2) (2020-06-20)


### Bug Fixes

* fix install: Add version and changelog.md into the bundle ([48f02d9](https://gitlab.com/blissfulreboot/python/git-workspace/commit/48f02d972ef0dfd3001ffb7d64b14a9832451b39))

## [1.0.1](https://gitlab.com/blissfulreboot/python/git-workspace/compare/v1.0.0...v1.0.1) (2020-06-20)


### Bug Fixes

* Check if repository exists when running in repository operations. ([0a47e47](https://gitlab.com/blissfulreboot/python/git-workspace/commit/0a47e4775a00e6e412cb9e1aa644ad94fce33af6))
* fix clone bug: workspace cannot be cloned unless in the workspace directory ([afe421d](https://gitlab.com/blissfulreboot/python/git-workspace/commit/afe421ddbbd881fd0389a3e08d822e30836f3ad8))
* Removed extra import, improved some prints and error handlings. ([e9dff72](https://gitlab.com/blissfulreboot/python/git-workspace/commit/e9dff7265e077e940dfd4cf72351be52a19432a5))
